#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-29
# File  : electrical_energy.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersEnvironment,
)
from cmk.gui.valuespec import Dictionary, DropdownChoice, Float,  Integer, TextInput, Tuple


def _item_spec_energy():
    return TextInput(
        title=_("Phase"), help=_("The identifier of the phase the power is related to.")
    )


def _parameter_valuespec_energy():
    return Dictionary(
        title=_('Parameters'),
        elements=[
            ("levels_upper",
             Tuple(
                 title=_("Upper levels for electrical energy"),
                 elements=[
                     Integer(title=_("warning at"), unit="Wh"),
                     Integer(title=_("critical at"), unit="Wh"),
                 ],
             )),
            ("levels_lower",
             Tuple(
                 title=_("Lower levels for electrical energy"),
                 elements=[
                     Integer(title=_("warning if below"), unit="Wh"),
                     Integer(title=_("critical if below"), unit="Wh"),
                 ],
             )),
            ("cost_kwh",
             Tuple(
                 title=_("Cost per kWh"),
                 orientation='horizontal',
                 elements=[
                     Float(title=_("Cost"), default_value=0.3),
                     DropdownChoice(
                         title=_("Currency"),
                         default_value='EUR',
                         choices=[
                             ('CHF', 'fr (franc suisse)'),
                             ('CZK', 'Kč (koruna česká)'),
                             ('DKK', 'kr. (dansk krone)'),
                             ('EUR', '€ (Euro)'),
                             ('GBP', '£ (Pound)'),
                             ('JPY', '¥ (Yen)'),
                             ('PLN', 'zł (Polski złoty)'),
                             ('USD', '$ (Dollar)'),
                         ]),
                 ],
             )),
        ],
        help=_(
            "Levels for the electrical energy consumption of a device "
            "like a UPS or a PDU. Several phases may be addressed independently."
        ),
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="energy_multiple",
        group=RulespecGroupCheckParametersEnvironment,
        item_spec=_item_spec_energy,
        parameter_valuespec=_parameter_valuespec_energy,
        title=lambda: _("Electrical Energy (several phases)"),
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="energy_single",
        group=RulespecGroupCheckParametersEnvironment,
        parameter_valuespec=_parameter_valuespec_energy,
        title=lambda: _("Electrical Energy (single phase)"),
    )
)
