#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-28
# File  : fritzbox_smarthome.py (WATO check plugin)
#


from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    MonitoringState,
    Tuple,
    TextInput,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)


def _parameter_valuespec_fritzbox_smarthome():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('present',
             MonitoringState(
                 title=_('Monitoring state for offline devices'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome,
        title=lambda: _('Fritz!Box Smarthome Devices')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome,
        title=lambda: _('Fritz!Box Smarthome Devices (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_thermostat():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('deviation',
             Tuple(
                 title=_('Deviation from target temperature'),
                 help=_('Deviation form target temperature in °C'),
                 elements=[
                     Integer(title=_('Warning'), default_value=3, unit=_('°C')),
                     Integer(title=_('Critical'), default_value=5, unit=_('°C')),
                 ])),
            ('state_off',
             MonitoringState(
                 title=_('Monitoring state if thermostat is off'),
                 default_value=0,
             )),
            ('state_on_error',
             MonitoringState(
                 title=_('Monitoring state on error'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_thermostat_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_thermostat,
        title=lambda: _('Fritz!Box Smarthome Thermostat'),
    )
)


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_thermostat_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_thermostat,
        title=lambda: _('Fritz!Box Smarthome Thermostat (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_battery():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('battery_low',
             MonitoringState(
                 title=_('Monitoring state on low battery'),
                 default_value=2,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_battery_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_battery,
        title=lambda: _('Fritz!Box Smarthome battery')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_battery_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_battery,
        title=lambda: _('Fritz!Box Smarthome battery (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)
